@@ -11,7 +11,7 @@ use HTML::ParseBrowser;
 use Mojo::ByteStream;
 use version 0.77;
 
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 sub register {
     my ($self, $app, $config) = @_;
@@ -63,6 +63,10 @@ sub register {
 
                           $local_base = $c->url_for( $local_base ) if $local_base;
 
+                          if ( $config->{no_file} and $config->{on_ready} ) {
+                              $file = sprintf '$(document).ready( function(){%s});', $file;
+                          }
+
                           $config->{no_file} ? 
                               qq~<script type="text/javascript">$file</script>~ :
                               qq~<script type="text/javascript" src="$local_base$file"></script>~;
@@ -132,7 +136,7 @@ Mojolicious::Plugin::JSLoader - move js loading to the end of the document
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -187,6 +191,15 @@ If set to a true value, you have to pass pure JavaScript
   # <script type="text/javascript">alert('test');</script>
   <% js_load("alert('test')", {no_file => 1}); %>
 
+=item * on_ready
+
+If set to a true value - in combination with a true value for I<no_file> - the javascript
+code is wrapped in C<$(document).ready( function(){...});>. This is quite handy when you
+have jquery installed and you want to run some javascript when the document is loaded.
+
+  # <script type="text/javascript">alert('test');</script>
+  <% js_load("alert('test')", {no_file => 1}); %>
+
 =item * inplace
 
 Do not load the javascript at the end of the page, but where C<js_load> is called.
@@ -284,7 +297,7 @@ Renee Baecker <reneeb@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Renee Baecker.
+This software is Copyright (c) 2017 by Renee Baecker.
 
 This is free software, licensed under:
 
